function [processedData meanProcessed] = simpleStatDPV_analysis(figTitle, inputData, PST_Data, DAC_Pots, calibrationDAC, ADC_ref, ADC_zero_GND, Rtia)
%DAC pots, vector of three values with [DACat255 DACat127 DACat0]
%calibrationDAC, the potential used to calculate the calibration potentials
%ADC_zero_GND, measurement of the potential between zero on the
%electrochemical cell and GND on the instrument.
%ADC_ref, the reference voltage used for the ADC conversion.
%Rtia, value of the feedback resistor used in the tia.

%Break down the recorded data into three sweeps, this line will need to be
%changed if the potential window or DPV paramters are altered.
sweepData(:,:,1) = inputData(1:59, :);
sweepData(:,:,2) = inputData(60:118, :); 
sweepData(:,:,3) = inputData(119:end, :);

%calculate step potential based upon measured calibration range
DACStep = (DAC_Pots(1,1)-DAC_Pots(3,1))./(calibrationDAC(1,1)-calibrationDAC(3,1)); 
DAC_Positive_255 = DAC_Pots(1,1)+((255-calibrationDAC(1,1)).*DACStep);
DAC_Negative_0 = DAC_Pots(3,1)-(calibrationDAC(3,1).*DACStep);

for i = 1:size(sweepData, 3)
    %calculate DAC potential:
    processedData(:,1,i) = DAC_Positive_255-(sweepData(:,1,i)/255).*((DAC_Positive_255-DAC_Negative_0));
    
    %calculate cell current:
    processedData(:,[2 3],i) = ((((sweepData(:,[2 3],i)/1024).*ADC_ref)-ADC_zero_GND)./Rtia).*1e6;
    
    %calculate net current:
    processedData(:,4, i) = processedData(:,3,i)-processedData(:,2,i);
  
end

%Plot a graphical summary of data:
meanProcessed = mean(processedData(:,4,:),3);

figure;
hold on;
plot(processedData(:,1,1), processedData(:,4,1),'-' ,'Color',[0,0.7,0.9]);
plot(processedData(:,1,1), processedData(:,4,2),'-.', 'Color',[0,0.7,0.9]);
plot(processedData(:,1,1), processedData(:,4,3),'--', 'Color',[0,0.7,0.9]);

plot(processedData(:,1,1), meanProcessed, 'b-', 'linewidth', 2);
plot(PST_Data(:,1), PST_Data(:,2), 'r-', 'linewidth', 1.5)
axis square;
lgd = legend('Sweep 1', 'Sweep 2', 'Sweep 3', 'Mean', 'PS Trace Data', 'Location','northwest');
box on;

title(lgd, figTitle);
xlabel('V (Volts)');
ylabel('I (\muA)');
